The dsmltf (Data Science and Machine Learning Training Functions) contains 
a set of functions to be used for educational purposes during study the  
Data Science course. Most of functions are described in the textbook 
available from the author by request on email shoukhov@mail.ru.
